is_area_mismatch

Function is_area_mismatch 

fn is_area_mismatch(total_area: f64, theoretical_area: f64) -> bool
The interface areas of a face should add up to the surface of the cell, a face with no geometric surface should carry no interface either